@@ -126,7 +126,7 @@ BEGIN {
     #   exit with error after _sig_handler call to output error and stack trace
     $SIG{__DIE__} = sub {
         if (not @_ or not defined $^S or $^S) {
-            &CORE::die(@_);
+            CORE::die(@_);
         } else {
             _sig_handler("perl die", scalar(caller), "@_");
         }
@@ -139,7 +139,7 @@ BEGIN {
     #   return after _sig_handler call to output error and stack trace
     $SIG{__WARN__} = sub {
         if (not @_ or not defined $^S) {
-            &CORE::warn(@_);
+            CORE::warn(@_);
         } else {
             _sig_handler("perl warn", scalar(caller), "@_");
         }
@@ -185,7 +185,6 @@ INIT {
             refer also to the Mnet::Opts::Set::Debug pragma module
             refer to perldoc Mnet::Log for more information
         ',
-        norecord    => 1,
     }) if $INC{"Mnet/Opts/Cli.pm"};
 
     # init --quiet option
@@ -199,7 +198,6 @@ INIT {
             refer also to the Mnet::Opts::Set::Quiet pragma module
             refer to perldoc Mnet::Log for more information
         ',
-        norecord    => 1,
     }) if $INC{"Mnet/Opts/Cli.pm"};
 
     # init --silent option
@@ -213,7 +211,6 @@ INIT {
             refer also to the Mnet::Opts::Set::Silent pragma module
             refer to perldoc Mnet::Log for more information
         ',
-        norecord    => 1,
     }) if $INC{"Mnet/Opts/Cli.pm"};
 
 # finished init code block
@@ -323,7 +320,7 @@ sub output {
         $script_name =~ s/^.*\///;
         my $started = "$script_name started";
         $started .= ", pid $$, ".localtime if not $INC{"Mnet/Log/Test.pm"};
-        NOTICE("script $started");
+        NOTICE($started);
         if ($self->{debug}) {
             output(undef, "dbg", 7, "Mnet::Version", Mnet::Version::info());
         }
