@@ -119,7 +119,7 @@ Refer to the documentation for specific output options below for more info.
         my $column = shift @{$opts->{columns}} // croak("missing column name");
         my $type = shift @{$opts->{columns}} // croak("missing column type");
         croak("invalid column name $column") if $column =~ /["\r\n]/;
-        $self->debug("new opts column $column ($type)");
+        $self->debug("new opts column = $column ($type)");
         $self->{_column_types}->{$column} = $type;
         push @{$self->{_column_order}}, $column;
         if ($type !~ /^(error|integer|string|time)$/) {
@@ -127,8 +127,12 @@ Refer to the documentation for specific output options below for more info.
         }
     }
 
+    # debug calls to display output option set for this object
+    $self->debug("new opts output = ".Mnet::Dump::line($self->{output}));
+
     # call _output method with no row arg to init output
     #   this allows parent or non-batch proc to output heading row, etc.
+    $self->debug("new calling to init _output");
     $self->_output;
 
     # finished new method, return Mnet::Report::Table object
@@ -297,7 +301,7 @@ info method.
 Note that the L<Mnet::Test> module --test command line option silently
 overrides all other report output options, outputting report data using
 the L<Mnet::Log> module if loaded or sending report output to stdout in
-L<Data::Dumper> format using the L<Mnet::Dump> module.
+L<Data::Dumper> format.
 
 Output options below can use /dev/stdout as the output file, which works nicely
 with the L<Mnet::Log> --silent option used with the L<Mnet::Batch> --batch
@@ -306,7 +310,7 @@ to be easily piped or redirected in aggregate as necessary.
 
 Note that /dev/stdout report output is not captured by the Mnet::Tee module,
 and might be missed if the L<Mnet::Log> module is not being used. In this case
-you should output report data to stdout yourself, maybe with L<Mnet::Dump>.
+you should output report data to stdout yourself.
 
 =cut
 
@@ -469,7 +473,7 @@ sub _output_dump {
     dump:$var:$file
 
 The dump output option writes one row per line in L<Data::Dumper> format
-prefixed by the specified variable name, using the L<Mnet::Dump> module.
+prefixed by the specified variable name.
 
 This dump output can be read back into a perl script as follows:
 
@@ -750,8 +754,6 @@ L<JSON>
 
 L<Mnet>
 
-L<Mnet::Dump>
-
 L<Mnet::Test>
 
 =cut
